%define server 1
Summary: A DNS (Domain Name System) server.
Name: bind
License: BSD-like
Group: System Environment/Daemons
Source: ftp://ftp.isc.org/isc/bind9/%{version}/bind-%{version}.tar.gz
Source1: named.sysconfig
Source2: named.init
Source3: named.logrotate
Source4: keygen.c
Source99: flexible.m4
#Patch0: bind-linux-capabilities.patch 
Url: http://www.isc.org/products/BIND/
Buildroot: %{_tmppath}/%{name}-%{version}-%{release}-root
%define BUILDROOT ~/rpmbuild/BUILD/%{name}-%{version}
Version: 9.10.4
Release: b2.0%{?dist}
Epoch: 31


BuildRequires: openssl-devel gcc glibc-devel >= 2.2.5-26 glibc-kernheaders >= 2.4-7.10 libtool pkgconfig json-c-devel >= 0.11

Requires(pre,preun): shadow-utils
Requires(post,preun): chkconfig
Requires(post): textutils, fileutils, sed
Requires: bind-utils bind-libs /bin/usleep
Requires: kernel >= 2.3
Requires: json-c >= 0.11

%description
BIND (Berkeley Internet Name Domain) is an implementation of the DNS
(Domain Name System) protocols. BIND includes a DNS server (named),
which resolves host names to IP addresses; a resolver library
(routines for applications to use when interfacing with DNS); and
tools for verifying that the DNS server is operating properly.

%package utils
Summary: Utilities for querying DNS name servers.
Group: Applications/System

%description utils
Bind-utils contains a collection of utilities for querying DNS (Domain
Name System) name servers to find out information about Internet
hosts. These tools will provide you with the IP addresses for given
host names, as well as other information about registered domains and
network addresses.

You should install bind-utils if you need to get information from DNS name
servers.

%package devel
Summary: Include files and libraries needed for bind DNS development.
Group: Development/Libraries
Requires: bind = %{version}

%description devel
The bind-devel package contains all the include files and the library
required for DNS (Domain Name System) development for BIND versions
9.x.x.

%prep
%setup -q -n %{name}-%{version}
#%patch0

##!! add a libtool macro for el4/5
cp -fp %{SOURCE99} libtool.m4

%build
#CHROOT=/etc/named/chroot
CHROOT=""
LTVERSION=`libtool --version |awk '{ print $4 }' |sed -e "s/\.//;s/\..*//g"`
if [ "$LTVERSION" -lt 14 ]; then
	export LTCONFIG_VERSION=1.3.5
fi
cp -f /usr/share/libtool/config.{guess,sub} .
export CFLAGS="$RPM_OPT_FLAGS"
if pkg-config openssl ; then
	export CFLAGS="$CFLAGS `pkg-config --cflags openssl`"
	export CPPFLAGS="$CPPFLAGS `pkg-config --cflags-only-I openssl`"
	export LDFLAGS="$LDFLAGS `pkg-config --libs-only-L openssl`"
fi

aclocal -I libtool.m4 --force; autoconf -f

%configure --with-libtool --with-openssl=/usr --enable-threads --disable-openssl-version-check
#make %{?_smp_mflags}   # seems to be broken: bugzilla:64868
make
#gzip -9 doc/rfc/*

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p ${RPM_BUILD_ROOT}/etc/{rc.d/init.d,logrotate.d}
mkdir -p ${RPM_BUILD_ROOT}/usr/{bin,lib,sbin,include}
mkdir -p ${RPM_BUILD_ROOT}/${CHROOT}/var/named
mkdir -p ${RPM_BUILD_ROOT}%{_mandir}/{man1,man5,man8}
mkdir -p ${RPM_BUILD_ROOT}/${CHROOT}/var/run/named

make DESTDIR=$RPM_BUILD_ROOT install
install -c -m 640 bin/rndc/rndc.conf $RPM_BUILD_ROOT/etc
install -c -m 755 contrib/scripts/named-bootconf.sh $RPM_BUILD_ROOT/usr/sbin/named-bootconf
install -c -m 755 %SOURCE2 $RPM_BUILD_ROOT/etc/rc.d/init.d/named
install -c -m 644 %SOURCE3 $RPM_BUILD_ROOT/etc/logrotate.d/named
touch $RPM_BUILD_ROOT/etc/rndc.key
cat << __EOF > $RPM_BUILD_ROOT/etc/rndc.key
key "rndckey" {
        algorithm       hmac-md5;
        secret "@KEY@";
};
__EOF
gcc $RPM_OPT_FLAGS -o $RPM_BUILD_ROOT/usr/sbin/dns-keygen %{SOURCE4}
cd $RPM_BUILD_ROOT%{_mandir}
mkdir -p ${RPM_BUILD_ROOT}/$CHROOT/etc/sysconfig
cp %{SOURCE1} ${RPM_BUILD_ROOT}/$CHROOT/etc/sysconfig/named

mv ${RPM_BUILD_ROOT}%{_mandir}/man1/nsupdate.1 ${RPM_BUILD_ROOT}%{_mandir}/man8/nsupdate.8
mv ${RPM_BUILD_ROOT}%{_mandir}/man1/nslookup.1 ${RPM_BUILD_ROOT}%{_mandir}/man8/nslookup.8
mv %{BUILDROOT}/bin/python/dnssec-checkds.py $RPM_BUILD_ROOT/usr/sbin/dnssec-checkds
mv %{BUILDROOT}/bin/python/dnssec-checkds.8 ${RPM_BUILD_ROOT}%{_mandir}/man8/dnssec-checkds.8
mv ${RPM_BUILD_ROOT}/usr/bin/bind9-config ${RPM_BUILD_ROOT}/usr/sbin/bind9-config

%if %server
%pre
/usr/sbin/useradd -c "Named" -u 25 \
	-s /sbin/nologin -r -d /var/named named 2>/dev/null || :

%post
/sbin/chkconfig --add named
if [ -f ${CHROOT}/etc/named.boot -a ! -f ${CHROOT}/etc/named.conf ]; then
  if [ -x /usr/sbin/named-bootconf ]; then
    cat ${CHROOT}/etc/named.boot | /usr/sbin/named-bootconf > ${CHROOT}/etc/named.conf
    chmod 644 ${CHROOT}/etc/named.conf
  fi
fi
if [ ! -e /etc/rndc.key.rpmnew ]; then
  sed -e "s/@KEY@/`/usr/sbin/dns-keygen`/" /etc/rndc.key >/etc/rndc.key.tmp
  mv -f /etc/rndc.key.tmp /etc/rndc.key
fi
chmod 0640 /etc/rndc.conf ${CHROOT}/etc/rndc.key
chown root:named /etc/rndc.conf ${CHROOT}/etc/rndc.key
/sbin/ldconfig
exit 0

%preun
if [ $1 = 0 ]; then
   /usr/sbin/userdel named 2>/dev/null || :
   /usr/sbin/groupdel named 2>/dev/null || :
   /sbin/chkconfig --del named
   [ -f /var/lock/subsys/named ] && /etc/rc.d/init.d/named stop >/dev/null 2>&1
fi
exit 0

%postun
if [ "$1" -ge 1 ]; then
	/etc/rc.d/init.d/named condrestart >/dev/null 2>&1 || :
fi
/sbin/ldconfig

%triggerpostun -- bind < 8.2.2_P5-15
/sbin/chkconfig --add named
/sbin/ldconfig
%endif

%clean
## Do not remove build root (comment out below)
rm -rf ${RPM_BUILD_ROOT} # ${RPM_BUILD_DIR}/%{name}-%{version}

%post utils -p /sbin/ldconfig

%postun utils -p /sbin/ldconfig

%if %server
%files
%defattr(-,root,root)
%doc CHANGES README
%doc doc/arm doc/misc
%config(noreplace) /etc/logrotate.d/named
%config /etc/rc.d/init.d/named
%config(noreplace) /etc/sysconfig/named
%verify(not size,not md5) %config(noreplace) %attr(0640,root,named) /etc/rndc.conf
%verify(not size,not md5) %config(noreplace) %attr(0640,root,named) /etc/rndc.key

%{_sbindir}/dnssec*
%{_sbindir}/lwresd
%{_sbindir}/named
%{_sbindir}/named-bootconf
%{_sbindir}/named-check*
%{_sbindir}/rndc*
%{_sbindir}/dns-keygen
%{_sbindir}/arpaname
%{_sbindir}/ddns-confgen
%{_sbindir}/genrandom
%{_sbindir}/isc-hmac-fixup
%{_sbindir}/named-journalprint
%{_sbindir}/nsec3hash
%{_sbindir}/bind9-config
%{_sbindir}/named-rrchecker

%config(noreplace) %{_sysconfdir}/bind.keys

%{_libdir}/libisccc.so.*
%{_libdir}/libisccfg.so.*
%{_libdir}/libbind9.so.*

%{_mandir}/man1/arpaname.1.gz
%{_mandir}/man1/isc-config.sh.1.gz
%{_mandir}/man1/bind9-config.1.gz
%{_mandir}/man1/named-rrchecker.1.gz
%{_mandir}/man5/rndc.conf.5*
%{_mandir}/man5/named.conf.5*
%{_mandir}/man8/rndc.8*
%{_mandir}/man8/named.8*
%{_mandir}/man8/lwresd.8*
%{_mandir}/man8/dnssec*.8*
%{_mandir}/man8/named-checkconf.8*
%{_mandir}/man8/named-checkzone.8*
%{_mandir}/man8/rndc-confgen.8*
%{_mandir}/man8/ddns-confgen.8.gz
%{_mandir}/man8/genrandom.8.gz
%{_mandir}/man8/isc-hmac-fixup.8.gz
%{_mandir}/man8/named-journalprint.8.gz
%{_mandir}/man8/nsec3hash.8.gz

%attr(-,named,named) %dir /var/named
%attr(-,named,named) %dir /var/run/named
%endif
 
%files utils
%defattr(-,root,root)
%{_bindir}/dig
%{_bindir}/host
%{_bindir}/delv
%{_bindir}/nslookup
%{_bindir}/nsupdate
%{_libdir}/libdns.so.*
%{_libdir}/libisc.so.*
%{_libdir}/liblwres.so.*
%{_libdir}/libirs.so.*
%{_mandir}/man1/host.1*
%{_mandir}/man1/delv.1*
%{_mandir}/man8/nsupdate.8*
%{_mandir}/man1/dig.1*
%{_mandir}/man8/nslookup.8*

%if %server
%files devel
%defattr(-,root,root)
%{_libdir}/*.so
%{_libdir}/*.la
%{_libdir}/*.a
%{_includedir}/*
%{_mandir}/man3/*
%{_bindir}/isc-config.sh
%endif

%changelog
* Thu Mar 17 2016 Ren Vermare <rene@vermare.nl> 9.10.4b2-0
- Initial build from version 9.10.4b2

* Thu Mar 10 2016 Ren Vermare <rene@vermare.nl> 9.10.3-P4.1
- Fix security issues described in CVE-2016-1285, CVE-2016-1286 and 
- CVE-2016-2088
- Build from version 9.10.3-P4.1

* Wed Jan 20 2016 Ren Vermare <rene@vermare.nl> 9.10.3-P3.1
- Fix security issues described in CVE-2015-8704 and CVE-2015-8705
- and fixes regression in authoritative server selection.
- Build from version 9.10.3-P3.1

* Wed Dec 16 2015 Ren Vermare <rene@vermare.nl> 9.10.3-P2.1
- Build version 9.10.3-P2.1
- Fix security issues described in CVE-2015-3193 (OpenSSL), 
- CVE-2015-8000 and CVE-2015-8461

* Wed Sep 16 2015 Ren Vermare <rene@vermare.nl> 9.10.3-1
- Build version 9.10.3-1 with json-c support

* Sat Sep  5 2015 Ren Vermare <rene@vermare.nl> 9.10.3rc1-1
- Build version 9.10.3rc1-1 with json-c support

* Mon Aug 10 2015 Ren Vermare <rene@vermare.nl> 9.10.3b1-2
- Build version 9.10.3b1-2 with json-c support

* Sat Aug  8 2015 Ren Vermare <rene@vermare.nl> 9.10.3b1-1
- Build from version 9.10.3b1-1

* Thu Feb 26 2015 Ren Vermare <rene@vermare.nl> 9.10.2-1
- Build from version 9.10.2-1

* Fri Feb 20 2015 Ren Vermare <rene@vermare.nl> 9.10.2rc2-1
- Build from version 9.10.2rc2-1

* Tue Feb 3 2015 Ren Vermare <rene@vermare.nl> 9.10.2rc1-1
- Build from version 9.10.2rc1-1

* Wed Jan 7 2015 Ren Vermare <rene@vermare.nl> 9.10.2b1-1
- Build from version 9.10.2b1
- Fix CVE-2014-8500 and CVE-2014-8680 and misc enhancements

* Mon Dec 8 2014 Ren Vermare <rene@vermare.nl> 9.10.1-P1.1
- Build from version 9.10.1-P1.1
- Misc security fixes and updates

* Tue Sep 23 2014 Ren Vermare <rene@vermare.nl> 9.10.1-1
- Build from version 9.10.1-1
- Misc security fixes and updates

* Mon Jun 16 2014 Ren Vermare <rene@vermare.nl> 9.10.0-P2-1
- Build from version 9.10.0-P2-1
- Fix security issue CVE-2014-3859 and CVE-2014-3214
- Misc new features

* Sat May 10 2014 Ren Vermare <rene@vermare.nl> 9.10.0-P1-1
- Build from version 9.10.0-P1-1
- Fix security issue CVE-2014-3214

* Wed Apr 30 2014 Ren Vermare <rene@vermare.nl> 9.10.0-1
- Build from version 9.10.0

* Sat Apr 26 2014 Ren Vermare <rene@vermare.nl> 9.10.0rc2-0
- Build from version 9.10.0rc2 (Release Candidate 2)
- Rename delve and delve.1.gz to delv and delv.1.gz

* Sat Apr 12 2014 Ren Vermare <rene@vermare.nl> 9.10.0rc1-0
- Build from version 9.10.0rc1 (Release Candidate 1)

* Wed Mar 26 2014 Ren Vermare <rene@vermare.nl> 9.10.0b2-0
- Build from version 9.10.0b2
- Change because named-bootconf.sh moved from 
- contrib/named-bootconf to contrib/scripts dir.
- Add delve, libirs.so.141.0.1, delve.1.gz to utils pkgs
- & named-rrchecker and named-rrchecker.1.gz to server pkgs.

* Mon Feb 3 2014 Ren Vermare <rene@vermare.nl> 9.9.5-0
- Build from version 9.9.5-0

* Mon Jan 13 2014 Ren Vermare <rene@vermare.nl> 9.9.4-P2.0
- Build from version 9.9.4-P2.0
- Fix security issue CVE-2013-6230 and CVE-2014-0591
- Remove Linux Capabilities patch

* Wed Oct 6 2013 Ren Vermare <rene@vermare.nl> 9.9.4-P1.1
- Build from version 9.9.4-P1.1
- Fix security issue CVE-2012-6230

* Thu Sep 26 2013 Ren Vermare <rene@vermare.nl> 9.9.4-2
- Build from version 9.9.4-2
- Add Linux Capabilities patch

* Sun Sep 22 2013 Ren Vermare <rene@vermare.nl> 9.9.4-1
- Build from version 9.9.4-1
- Enabled full-report

* Sat Sep 21 2013 Ren Vermare <rene@vermare.nl> 9.9.4-0
- Build from version 9.9.4-0
- Several Security fixes, bug fixes for DNSSEC, RPZ and
- configuration modules and Response Rate Limiting (RRL).

* Thu Aug 1 2013 Ren Vermare <rene@vermare.nl> 9.9.4b1.1
- Initial build from version 9.9.4b1

* Sat Jul 27 2013 Ren Vermare <rene@vermare.nl> 9.9.3-P2.1
- Security Fix; CVE-2013-4854

* Thu Jun 6 2013 Ren Vermare <rene@vermare.nl> 9.9.3-P1.1
- Security Fix; CVE-2013-3919 (RUNTIME_CHECK error in
- resolver.c).

* Wed May 29 2013 Ren Vermare <rene@vermare.nl> 9.9.3-1
- Misc Security Fixes (CVE-2013-2266)  [RT #32688], (CVE-2012-5688)
- [RT #30792 / #30996], (CVE-2012-5689) [RT #32141].
- New Features [RT #33355], [RT #28098], [RT #33082] &
- [RT #31836]

* Wed Mar 27 2013 Ren Vermare <rene@vermare.nl> 9.9.2-P2.1
- Misc Security Fixes (RT #32688, #3388, RT #30996, RT #30792
- RT #31090, RT #30416, RT #30025, RT #29644, RT #29539 & 
- #30233.
- New Features (RT #21918, RT #28099, RT #23673 & RT #29228).

* Sat Feb 9 2013 Ren Vermare <rene@vermare.nl> 9.9.2-P1.2
- Rebuild of version 9.9.2
- Add dnssec-checkds to package bind

* Tue Jan 29 2013 Ren Vermare <rene@vermare.nl> 9.9.2-P1.1
- Initial build of version 9.9.2

* Sun Jan 20 2013 Ren Vermare <rene@vermare.nl> 9.8.4-P1.1
- Misc bug fixes and security updates: RT #3388, RT #30996,
- [CVE-2012-5688] [RT #30792], [RT #21918]

* Fri Oct 26 2012 Ren Vermare <rene@vermare.nl> 9.7.7-1
- Initial build of version 9.7.7

* Wed Oct 10 2012 Ren Vermare <rene@vermare.nl> 9.7.6-P4.1
- Security Fixes (RT #31090, RT #30416, RT #30025 & RT #29644)
- Misc bug fixes
- Feature change (RT #28989)

* Wed Sep 12 2012 Ren Vermare <rene@vermare.nl> 9.7.6-P3.1
- Security Fixes (RT #30416, RT #30025 & RT #29644)
- Misc bug fixes 
- Feature change (RT #28989)

* Tue Jul 24 2012 Ren Vermare <rene@vermare.nl> 9.7.6-P2.1
- Security Fixes (RT #30025 & RT #29644)
- Misc bug fixes
- Feature change (RT #28989)

* Fri Jun 8 2012 Ren Vermare <rene@vermare.nl> 9.7.6-P1.1
- Fix security issue (RT #29644)

* Tue May 22 2012 Ren Vermare <rene@vermare.nl> 9.7.6-1
- BIND now recognizes the TLSA resource record type.
- (RT #28989)
- Misc Bug Fixes.

* Tue May 2 2012 Ren Vermare <rene@vermare.nl> 9.7.5-2
- Fix bug #RT27995

* Fri Apr 27 2012 Ren Vermare <rene@vermare.nl> 9.7.5.1
- Build of version 9.7.5.1
- Misc bug fixes
- Remove rfc's from package

* Wed Nov 16 2011 Ren Vermare <rene@vermare.nl> 9.7.4-P1.1
- Build of version 9.7.4-P1.1
- Fix CVE-2011-4313

* Wed Aug 10 2011 Ren Vermare <rene@vermare.nl> 9.7.4-1
- Build of version 9.7.4-1
- Fix CVE-2011-1910 and CVE-2011-2464
- Test added to check the apex NSEC3 records
- Added a tool able to generate malformed packets

* Thu Jul 7 2011 Ren Vermare <rene@vermare.nl> 9.7.3-P3.1
- Build of version 9.7.3-P3.1
- Fix CVE-2011-2464

* Sun May 29 2011 Ren Vermare <rene@vermare.nl> 9.7.3-P1.1
- Build of version 9.7.3-P1.1
- Fix CVE-2011-1910 & RT #24631

* Sat Apr 16 2011 Ren Vermare <rene@vermare.nl> 9.7.3-2
- Removed the 'bind-manpages' tarball from the package 

* Sat Apr 16 2011 Ren Vermare <rene@vermare.nl> 9.7.3-1
- Build of version 9.7.3-1 for el4

* Sun Mar 20 2011 Ren Vermare <rene@vermare.nl> 9.7.2-P3.2
- Build of version 9.7.2-P3.2 for el4

* Wed Jan 19 2011 Ren Vermare <rene@vermare.nl> 9.7.2-P3.1
- Build of version 9.7.2-P3.1

* Fri Jul 31 2009 Ren Vermare <rene@vermare.nl> 9.4.3-P3.1
- Build of (sub)version 9.4.3-P3.1
- Improve rndc.conf

* Thu Jul 30 2009 Ren Vermare <rene@vermare.nl> 9.4.3-P3
- Build of version 9.4.3-P3
- Moved manpages nslookup & nsupdate from man1 to man8 dir
- Add libbind9.so.* to libdir

* Tue Jan 24 2003 Daniel Walsh <dwalsh@redhat.com> 9.2.1-16
- Put a sleep in restart to make sure stop completes

* Wed Jan 22 2003 Tim Powers <timp@redhat.com>
- rebuilt

* Tue Jan 7 2003 Daniel Walsh <dwalsh@redhat.com> 9.2.1-14
- Separate /etc/rndc.key to separate file

* Tue Jan 7 2003 Nalin Dahyabhai <nalin@redhat.com> 9.2.1-13
- Use openssl's pkgconfig data, if available, at build-time.

* Mon Jan 6 2003 Daniel Walsh <dwalsh@redhat.com> 9.2.1-12
- Fix log rotate to use service named reload
- Change service named reload to give success/failure message [73770]
- Fix File checking [75710]
- Begin change to automatically run in CHROOT environment

* Tue Dec 24 2002 Daniel Walsh <dwalsh@redhat.com> 9.2.1-10
- Fix startup script to work like all others.

* Mon Dec 16 2002 Daniel Walsh <dwalsh@redhat.com> 9.2.1-9
- Fix configure to build on x86_64 platforms

* Wed Aug 07 2002 Karsten Hopp <karsten@redhat.de>
- fix #70583,  doesn't build on IA64 

* Tue Jul 30 2002 Karsten Hopp <karsten@redhat.de> 9.2.1-8
- bind-utils shouldn't require bind

* Mon Jul 22 2002 Karsten Hopp <karsten@redhat.de> 9.2.1-7
- fix name of pidfine in logrotate script (#68842)
- fix owner of logfile in logrotate script (#41391)
- fix nslookup and named.conf man pages (output on stderr)
  (#63553, #63560, #63561, #54889, #57457)
- add rfc1912 (#50005)
- gzip all rfc's
- fix typo in keygen.c (#54870)
- added missing manpages (#64065)
- shutdown named properly with rndc stop (#62492)
- /sbin/nologin instead of /bin/false (#68607)
- move nsupdate to bind-utils (where the manpage already was) (#66209, #66381)
- don't kill initscript when rndc fails (reload)    (#58750)


* Mon Jun 24 2002 Bernhard Rosenkraenzer <bero@redhat.com> 9.2.1-5
- Fix #65975

* Fri Jun 21 2002 Tim Powers <timp@redhat.com>
- automated rebuild

* Thu May 23 2002 Tim Powers <timp@redhat.com>
- automated rebuild

* Thu May  9 2002 Bernhard Rosenkraenzer <bero@redhat.com> 9.2.1-2
- Move libisccc, lib isccfg and liblwres from bind-utils to bind,
  they're not required if you aren't running a nameserver.

* Fri May 03 2002 Florian La Roche <Florian.LaRoche@redhat.de>
- update to 9.2.1 release

* Thu Mar 14 2002 Bernhard Rosenkraenzer <bero@redhat.com> 9.2.0-8
- Merge 30+ bug fixes from 9.2.1rc1 code

* Mon Mar 11 2002 Bernhard Rosenkraenzer <bero@redhat.com> 9.2.0-7
- Don't exit if /etc/named.conf doesn't exist if we're running
  chroot (#60868)
- Revert Elliot's changes, we do require specific glibc/glibc-kernheaders
  versions or bug #58335 will be back. "It compiles, therefore it works"
  isn't always true.

* Thu Feb 28 2002 Elliot Lee <sopwith@redhat.com> 9.2.0-6
- Fix BuildRequires (we don't need specific glibc/glibc-kernheaders 
versions).
- Use _smp_mflags

* Wed Feb 20 2002 Bernhard Rosenkraenzer <bero@redhat.com> 9.2.0-4
- rebuild, require recent autoconf, automake (#58335)

* Fri Jan 25 2002 Tim Powers <timp@redhat.com>
- rebuild against new libssl

* Wed Jan 09 2002 Tim Powers <timp@redhat.com>
- automated rebuild

* Tue Nov 27 2001 Bernhard Rosenkraenzer <bero@redhat.com> 9.2.0-1
- 9.2.0

* Thu Nov 22 2001 Bernhard Rosenkraenzer <bero@redhat.com> 9.2.0-0.rc10.2
- 9.2.0rc10

* Mon Nov  5 2001 Bernhard Rosenkraenzer <bero@redhat.com> 9.2.0-0.rc8.2
- Fix up rndc.conf (#55574)

* Thu Oct 25 2001 Bernhard Rosenkraenzer <bero@redhat.com> 9.2.0-0.rc8.1
- rc8
- Enforce --enable-threads

* Mon Oct 22 2001 Bernhard Rosenkraenzer <bero@redhat.com> 9.2.0-0.rc7.1
- 9.2.0rc7
- Use rndc status for "service named status", it's supposed to actually
  work in 9.2.x.

* Wed Oct  3 2001 Bernhard Rosenkraenzer <bero@redhat.com> 9.2.0-0.rc5.1
- 9.2.0rc5
- Fix rpm --rebuild with ancient libtool versions (#53938, #54257)

* Tue Sep 25 2001 Bernhard Rosenkraenzer <bero@redhat.com> 9.2.0-0.rc4.1
- 9.2.0rc4

* Fri Sep 14 2001 Bernhard Rosenkraenzer <bero@redhat.com> 9.2.0-0.rc3.1
- 9.2.0rc3
- remove ttl patch, I don't think we need this for 8.0.
- remove dig.1.bz2 from the bind8-manpages tar file, 9.2 has a new dig man page
- add lwres* man pages to -devel

* Mon Sep  3 2001 Bernhard Rosenkraenzer <bero@redhat.com> 9.1.3-4
- Make sure /etc/rndc.conf isn't world-readable even after the
  %post script inserted a random key (#53009)

* Thu Jul 19 2001 Bernhard Rosenkraenzer <bero@redhat.com> 9.1.3-3
- Add build dependencies (#49368)
- Make sure running service named start several times doesn't create
  useless processes (#47596)
- Work around the named parent process returning 0 even if the config
  file is broken (it's parsed later by the child processes) (#45484)

* Mon Jul 16 2001 Bernhard Rosenkraenzer <bero@redhat.com> 9.1.3-2
- Don't use rndc status, it's not yet implemented (#48839)

* Sun Jul 08 2001 Florian La Roche <Florian.LaRoche@redhat.de>
- update to 9.1.3 release

* Tue Jul  3 2001 Bernhard Rosenkraenzer <bero@redhat.com> 9.1.3-0.rc3.1
- Fix up rndc configuration and improve security (#46586)

* Tue Jun 26 2001 Bernhard Rosenkraenzer <bero@redhat.com> 9.1.3-0.rc2.2
- Sync with caching-nameserver-7.1-6

* Mon Jun 25 2001 Bernhard Rosenkraenzer <bero@redhat.com> 9.1.3-0.rc2.1
- Update to rc2

* Fri Jun  1 2001 Bernhard Rosenkraenzer <bero@redhat.com> 9.1.3-0.rc1.3
- Remove resolv.conf(5) man page, it's now in man-pages

* Thu May 31 2001 Bernhard Rosenkraenzer <bero@redhat.com> 9.1.3-0.rc1.2
- Add named.conf man page from bind 8.x (outdated, but better than nothing,
  #42732)
- Rename the rndc key (#42895)
- Add dnssec* man pages

* Mon May 28 2001 Bernhard Rosenkraenzer <bero@redhat.com> 9.1.3-0.rc1.1
- 9.1.3rc1
- s/Copyright/License/

* Mon May  7 2001 Bernhard Rosenkraenzer <bero@redhat.com> 9.1.2-1
- 9.1.2 final. No changes between 9.1.2-0.rc1.1 and this one, except for
  the version number, though.

* Thu May  3 2001 Bernhard Rosenkraenzer <bero@redhat.com> 9.1.2-0.rc1.1
- 9.1.2rc1

* Thu Mar 29 2001 Bernhard Rosenkraenzer <bero@redhat.com> 9.1.1-1
- 9.1.1

* Thu Mar 15 2001 Bernhard Rosenkraenzer <bero@redhat.com> 9.1.0-10
- Merge fixes from 9.1.1rc5

* Sun Mar 11 2001 Bernhard Rosenkraenzer <bero@redhat.com> 9.1.0-9
- Work around bind 8 -> bind 9 migration problem when using buggy zone files:
  accept zones without a TTL, but spew out a big fat warning. (#31393)

* Thu Mar  8 2001 Bernhard Rosenkraenzer <bero@redhat.com>
- Add fixes from rc4

* Fri Mar  2 2001 Nalin Dahyabhai <nalin@redhat.com>
- rebuild in new environment

* Thu Mar  1 2001 Bernhard Rosenkraenzer <bero@redhat.com>
- killall -HUP named if rndc reload fails (#30113)

* Tue Feb 27 2001 Bernhard Rosenkraenzer <bero@redhat.com>
- Merge some fixes from 9.1.1rc3

* Tue Feb 20 2001 Bernhard Rosenkraenzer <bero@redhat.com>
- Don't use the standard rndc key from the documentation, instead, create a random one
  at installation time (#26358)
- Make /etc/rndc.conf readable by user named only, it contains secret keys

* Tue Feb 20 2001 Bernhard Rosenkraenzer <bero@redhat.com>
- 9.1.1 probably won't be out in time, revert to 9.1.0 and apply fixes
  from 9.1.1rc2
- bind requires bind-utils (#28317)

* Tue Feb 13 2001 Bernhard Rosenkraenzer <bero@redhat.com>
- Update to rc2, fixes 2 more bugs
- Fix build with glibc >= 2.2.1-7

* Thu Feb  8 2001 Bernhard Rosenkraenzer <bero@redhat.com>
- Update to 9.1.1rc1; fixes 17 bugs (14 of them affecting us;
  1 was fixed in a Red Hat patch already, 2 others are portability
  improvements)

* Wed Feb  7 2001 Bernhard Rosenkraenzer <bero@redhat.com>
- Remove initscripts 5.54 requirement (#26489)

* Mon Jan 29 2001 Bernhard Rosenkraenzer <bero@redhat.com>
- Add named-checkconf, named-checkzone (#25170)

* Mon Jan 29 2001 Trond Eivind Glomsrd <teg@redhat.com>
- use echo, not gprintf

* Wed Jan 24 2001 Bernhard Rosenkraenzer <bero@redhat.com>
- Fix problems with $GENERATE
  Patch from Daniel Roesen <droesen@entire-systems.com>
  Bug #24890

* Thu Jan 18 2001 Bernhard Rosenkraenzer <bero@redhat.com>
- 9.1.0 final

* Sat Jan 13 2001 Bernhard Rosenkraenzer <bero@redhat.com>
- 9.1.0rc1
- i18nify init script
- bzip2 source to save space

* Thu Jan 11 2001 Bernhard Rosenkraenzer <bero@redhat.com>
- Fix %%postun script

* Tue Jan  9 2001 Bernhard Rosenkraenzer <bero@redhat.com>
- 9.1.0b3

* Mon Jan  8 2001 Bernhard Rosenkraenzer <bero@redhat.com>
- Add named.conf man page from bind8 (#23503)

* Sun Jan  7 2001 Bernhard Rosenkraenzer <bero@redhat.com>
- Make /etc/rndc.conf and /etc/sysconfig/named noreplace
- Make devel require bind = %%{version} rather than just bind

* Sun Jan  7 2001 Bernhard Rosenkraenzer <bero@redhat.com>
- Fix init script for real

* Sat Jan  6 2001 Bernhard Rosenkraenzer <bero@redhat.com>
- Fix init script when ROOTDIR is not set

* Thu Jan  4 2001 Bernhard Rosenkraenzer <bero@redhat.com>
- Add hooks for setting up named to run chroot (RFE #23246)
- Fix up requirements

* Fri Dec 29 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- 9.1.0b2

* Wed Dec 20 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- Move run files to /var/run/named/ - /var/run isn't writable
  by the user we're running as. (Bug #20665)

* Tue Dec 19 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- Fix reverse lookups (#22272)
- Run ldconfig in %post utils

* Tue Dec 12 2000 Karsten Hopp <karsten@redhat.de>
- fixed logrotate script (wrong path to kill)
- include header files in -devel package
- bugzilla #22049, #19147, 21606

* Fri Dec  8 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- 9.1.0b1 (9.1.0 is in our timeframe and less buggy)

* Mon Nov 13 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- 9.0.1

* Mon Oct 30 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- Fix initscript (Bug #19956)
- Add sample rndc.conf (Bug #19956)
- Fix build with tar 1.13.18

* Tue Oct 10 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- Add some missing man pages (taken from bind8) (Bug #18794)

* Sun Sep 17 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- 9.0.0 final

* Wed Aug 30 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- rc5
- fix up nslookup

* Thu Aug 24 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- rc4

* Thu Jul 13 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- 9.0.0rc1

* Wed Jul 12 2000 Prospector <bugzilla@redhat.com>
- automatic rebuild

* Sun Jul  9 2000 Florian La Roche <Florian.LaRoche@redhat.de>
- add "exit 0" for uninstall case

* Fri Jul  7 2000 Florian La Roche <Florian.LaRoche@redhat.de>
- add prereq init.d and cleanup install section

* Fri Jun 30 2000 Trond Eivind Glomsrd <teg@redhat.com>
- fix the init script

* Wed Jun 28 2000 Nalin Dahyabhai <nalin@redhat.com>
- make libbind.a and nslookup.help readable again by setting INSTALL_LIB to ""

* Mon Jun 26 2000 Bernhard Rosenkrnzer <bero@redhat.com>
- Fix up the initscript (Bug #13033)
- Fix build with current glibc (Bug #12755)
- /etc/rc.d/init.d -> /etc/init.d
- use %%{_mandir} rather than /usr/share/man

* Mon Jun 19 2000 Bill Nottingham <notting@redhat.com>
- fix conflict with man-pages
- remove compatibilty chkconfig links
- initscript munging

* Wed Jun 14 2000 Nalin Dahyabhai <nalin@redhat.com>
- modify logrotate setup to use PID file
- temporarily disable optimization by unsetting $RPM_OPT_FLAGS at build-time
- actually bump the release this time

* Sun Jun  4 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- FHS compliance

* Mon Apr 17 2000 Nalin Dahyabhai <nalin@redhat.com>
- clean up restart patch

* Mon Apr 10 2000 Nalin Dahyabhai <nalin@redhat.com>
- provide /var/named (fix for bugs #9847, #10205)
- preserve args when restarted via ndc(8) (bug #10227)
- make resolv.conf(5) a link to resolver(5) (bug #10245)
- fix SYSTYPE bug in all makefiles
- move creation of named user from %%post into %%pre

* Mon Feb 28 2000 Bernhard Rosenkrnzer <bero@redhat.com>
- Fix TTL (patch from ISC, Bug #9820)

* Wed Feb 16 2000 Bernhard Rosenkrnzer <bero@redhat.com>
- fix typo in spec (it's %post, without a leading blank) introduced in -6
- change SYSTYPE to linux

* Sat Feb 11 2000 Bill Nottingham <notting@redhat.com>
- pick a standard < 100 uid/gid for named

* Thu Feb 04 2000 Elliot Lee <sopwith@redhat.com>
- Pass named a '-u named' parameter by default, and add/remove user.

* Thu Feb  3 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- fix host mx bug (Bug #9021)

* Mon Jan 31 2000 Cristian Gafton <gafton@redhat.com>
- rebuild to fix dependencies
- man pages are compressed

* Wed Jan 19 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- It's /usr/bin/killall, not /usr/sbin/killall (Bug #8063)

* Mon Jan 17 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- Fix up location of named-bootconf.pl and make it executable
  (Bug #8028)
- bind-devel requires bind

* Mon Nov 15 1999 Bernhard Rosenkraenzer <bero@redhat.com>
- update to 8.2.2-P5

* Wed Nov 10 1999 Bill Nottingham <notting@redhat.com>
- update to 8.2.2-P3

* Tue Oct 12 1999 Cristian Gafton <gafton@redhat.com>
- add patch to stop a cache only server from complaining about lame servers
  on every request.

* Fri Sep 24 1999 Preston Brown <pbrown@redhat.com>
- use real stop and start in named.init for restart, not ndc restart, it has
  problems when named has changed during a package update... (# 4890)

* Fri Sep 10 1999 Bill Nottingham <notting@redhat.com>
- chkconfig --del in %preun, not %postun

* Mon Aug 16 1999 Bill Nottingham <notting@redhat.com>
- initscript munging

* Mon Jul 26 1999 Bill Nottingham <notting@redhat.com>
- fix installed chkconfig links to match init file

* Sat Jul  3 1999 Jeff Johnson <jbj@redhat.com>
- conflict with new (in man-1.24) man pages (#3876,#3877).

* Tue Jun 29 1999 Bill Nottingham <notting@redhat.com>
- fix named.logrotate (wrong %SOURCE)

* Fri Jun 25 1999 Jeff Johnson <jbj@redhat.com>
- update to 8.2.1.
- add named.logrotate (#3571).
- hack around egcs-1.1.2 -m486 bug (#3413, #3485).
- vet file list.

* Fri Jun 18 1999 Bill Nottingham <notting@redhat.com>
- don't run by default

* Sun May 30 1999 Jeff Johnson <jbj@redhat.com>
- nslookup fixes (#2463).
- missing files (#3152).

* Sat May  1 1999 Stepan Kasal <kasal@math.cas.cz>
- nslookup patched:
  to count numRecords properly
  to fix subsequent calls to ls -d
  to parse "view" and "finger" commands properly
  the view hack updated for bind-8 (using sed)

* Wed Mar 31 1999 Bill Nottingham <notting@redhat.com>
- add ISC patch
- add quick hack to make host not crash
- add more docs

* Fri Mar 26 1999 Cristian Gafton <gafton@redhat.com>
- add probing information in the init file to keep linuxconf happy
- dont strip libbind

* Sun Mar 21 1999 Cristian Gafton <gafton@redhat.com> 
- auto rebuild in the new build environment (release 3)

* Wed Mar 17 1999 Preston Brown <pbrown@redhat.com>
- removed 'done' output at named shutdown.

* Tue Mar 16 1999 Cristian Gafton <gafton@redhat.com>
- version 8.2

* Wed Dec 30 1998 Cristian Gafton <gafton@redhat.com>
- patch to use the __FDS_BITS macro
- build for glibc 2.1

* Wed Sep 23 1998 Jeff Johnson <jbj@redhat.com>
- change named.restart to /usr/sbin/ndc restart

* Sat Sep 19 1998 Jeff Johnson <jbj@redhat.com>
- install man pages correctly.
- change K10named to K45named.

* Wed Aug 12 1998 Jeff Johnson <jbj@redhat.com>
- don't start if /etc/named.conf doesn't exist.

* Sat Aug  8 1998 Jeff Johnson <jbj@redhat.com>
- autmagically create /etc/named.conf from /etc/named.boot in %post
- remove echo in %post

* Wed Jun 10 1998 Jeff Johnson <jbj@redhat.com>
- merge in 5.1 mods

* Sun Apr 12 1998 Manuel J. Galan <manolow@step.es>
- Several essential modifications to build and install correctly.
- Modified 'ndc' to avoid deprecated use of '-'

* Mon Dec 22 1997 Scott Lampert <fortunato@heavymetal.org>
- Used buildroot
- patched bin/named/ns_udp.c to use <libelf/nlist.h> for include
  on Redhat 5.0 instead of <nlist.h>

